.ds-primary-title {
    color: #839496;
}

.bs-callout-neutral {
  background-color: #eee8d5;
  border-color: #D6D0BC;
}

.ds-dashboard .well {
  background-color: rgba(0,0,0,0.07)
}

.ds-singlegraph span.value {
    text-shadow: 1px 1px white;
}

.ds-singlestat .unit,
.ds-jumbotron-singlestat .unit {
    color: #93a1a1;
}

.ds-singlestat h3,
.ds-jumbotron-singlestat h3 {
    color: #839496;
}

#ds-tooltip {
    color: #586e75;
    background-color: #FFFFED;
    border: 1px solid #586e75;
}

.alert-neutral {
    background-color: #eee8d5;
    border-color: #D6D0BC;
}

/* -----------------------------------------------------------------------------
   Edit mode headers
   ----------------------------------------------------------------------------- */

/*
 * Section
 */

.ds-badge-section {
    background-color: #387AA3;
}

.ds-edit-bar-section {
    background-color: #9DC2D3;
    border: 1px solid #387AA3;
}

/*
 * Row
 */

.ds-badge-row {
    background-color: #649EB9;
}

.ds-edit-bar-row {
    border: 1px solid #649EB9;
    background-color: #D9EDF7;
}

.ds-row.ds-edit {
    border: 1px solid #649EB9;
    border-radius: 4px;
}

/*
 * Cell
 */

.ds-badge-cell {
    background-color: #649EB9;
    border: 1px solid #9DC2D3;
}
.ds-edit-bar-cell {
    background-color: #E3F7FF;
    border: 1px solid #9DC2D3;
}

/*
 * Item
 */

.ds-badge-item {
    background-color: #D9EDF7;
    color: #387AA3;
    border: 1px solid #649EB9;
}

.ds-edit-bar-item {
    background-color: #FAFAFA;
    border: 1px solid #649EB9;
}

/* -----------------------------------------------------------------------------
   Select2
   ----------------------------------------------------------------------------- */

.select2-container .select2-choices .select2-search-field input,
.select2-container .select2-choice,
.select2-container .select2-choices,
.select2-search input,
.select2-drop
{
    background: #FEFCF6;
}
