<div class="alert alert-info" data-ds-show="edit" style="display:none; margin-top:1em;">
  <div class="ds-dashboard-info-edit-panel">
    <div class="row">
      <div class="col-md-12">
        <p>
          <h2><i class="fa fa-lg fa-wrench"></i> Coming soon to a dashboard near you</h2>
        </p>
      </div>
    </div>
  </div>
</div>
