
/* Bootstrap tweaks */

.well,
.breadcrumb {
  -webkit-box-shadow: rgba(255, 255, 255, 0.1) 0 1px 0, rgba(0, 0, 0, 0.8) 0 1px 7px 0px inset;
  -moz-box-shadow: rgba(255, 255, 255, 0.1) 0 1px 0, rgba(0, 0, 0, 0.8) 0 1px 7px 0px inset;
  box-shadow: rgba(255, 255, 255, 0.1) 0 1px 0, rgba(0, 0, 0, 0.8) 0 1px 7px 0px inset;
  background: #202020;
  background-color: rgba(0, 0, 0, 0.3);
  border: 0;
  filter: progid:DXImageTransform.Microsoft.gradient(startColorstr=#88000000,endColorstr=#88000000);
}

hr {
  -webkit-box-shadow: rgba(255, 255, 255, 0.07) 0 1px 0;
  -moz-box-shadow: rgba(255, 255, 255, 0.07) 0 1px 0;
  box-shadow: rgba(255, 255, 255, 0.07) 0 1px 0;
  border-bottom: 1px solid #121212;
  border-top: none;
}

.page-header {
  box-shadow: rgba(255, 255, 255, 0.07) 0 1px 0;
  border-bottom: 1px solid #121212;
}

/* nvd3 tweaks for darkstrap */

.nvtooltip {
  background-color: #586e75;
  color: #fdf6e3;
  border: 1px solid #839496;
}

.nvd3 text {
    fill: #657b83;
}

.nv-legend-text {
    fill: #657b83;
}

.nvd3 .tick line {
    stroke: #073642;
}

.nvd3 .nv-axis path {
    stroke: #073642;
}

.nv-label text {
    stroke: #657b83;
}

/* Application Styles */

.ds-grid h1,
.ds-grid h2
{
    color: #eee8d5;
}

.ds-grid h1 small,
.ds-grid h2 small
{
    color: #586e75;
}

.ds-item h1,
.ds-item h2,
.ds-item h3,
.ds-item h4,
.ds-item h5,
.ds-item h6 {
    color: #93a1a1;
}

.ds-singlestat h3 {
    color: #959588;
}

.well .ds-singlestat h3 {
  color: #b58900;
}

.ds-singlestat p {
    color:white;
}

.ds-singlestat .unit,
.ds-jumbotron-singlestat .unit {
    color: 586e75;
}

.ds-jumbotron-singlestat .value {
    color: white;
}

.ds-jumbotron-singlestat h3 {
    color: #a6a699;
}

h1 .ds-primary-title {
    color: #586e75;

}

h1 .ds-secondary-title {
    color: #eee8d5;
}

.breadcrumb .active {
    color: #586e75;
}

h1.page-title .ds-summary {
    color: #93a1a1;
}

.ds-time-container h2 {
    color: #ddd;
}

.ds-warning,
.ds-warning h3,
.ds-warning .value,
.ds-warning .unit {
    color: #FF9E3F;
}

.ds-danger,
.ds-danger h3,
.ds-danger .value,
.ds-danger .unit {
    color: #FF0000;
}

.badge-neutral {
  color: #222;
}

.ds-singlegraph span.value {
    text-shadow: 1px 1px black;
}

/* Alerts */

.alert-neutral,
.bs-callout-neutral {
    background-color: #494949;
    border-color: #686868;
}

.alert-info,
.bs-callout-info {
    background-color: #0F3941;
    border-color: #145561;
}

.alert-success,
.bs-callout-success {
    background-color: #35492C;
    border-color: #436824;
}

.alert-warning,
.bs-callout-warning {
    background-color: #6F3701;
    border-color: #A25103;
}

.alert-danger,
.bs-callout-danger {
    background-color: #661615;
    border-color: #9C2927;
}

/* -----------------------------------------------------------------------------
 Edit mode headers
 ----------------------------------------------------------------------------- */

/*
 * Section
 */

.ds-badge-section {
    background-color: #333;
}

.ds-edit-bar-section {
    background-color: #111;
    border: 1px solid #444;
}

/*
 * Row
 */

.ds-badge-row {
    background-color: #555;
}

.ds-edit-bar-row {
    border: 1px solid #555;
    background-color: #222;
}

.ds-row.ds-edit {
    border: 1px solid #555;
}

/*
 * Cell
 */

.ds-badge-cell {
    border: 1px solid #555;
    color: #002b36;
}

.ds-edit-bar-cell {
    background-color: #444;
    border: 1px solid #777;
}

/*
 * Item
 */

.ds-badge-item {
    background-color: #777;
    color: white;
    border: 1px solid #AAA;
}

.ds-edit-bar-item {
    background-color: #555;
    border: 1px solid #777;
}

#ds-tooltip {
    color: #93a1a1;
    background-color: #073642;
    border: 1px solid #657b83;
}


/* -----------------------------------------------------------------------------
   Select2
   ----------------------------------------------------------------------------- */

.select2-container .select2-choices .select2-search-field input,
.select2-container .select2-choice,
.select2-container .select2-choices,
.select2-search input,
.select2-drop
{
    background: #073642;
    border-color: #586E75;
    color: #EEE8D5;
}

.select2-arrow {
    border-left: 1px solid #586E75;
}
