<div class="row">

  <!-- Range picker -->
  <div class="col-md-7">
    <div data-ds-hide="edit">
      {% include "snippets/range-picker.html" %}
    </div>
  </div>

  <!-- toolbar -->
  <div class="col-md-5">
    <div class="btn-toolbar pull-right">


      <div class="btn-group" data-ds-show="edit" style="display:none">
        <!-- Delete button -->
        <button type="button"
                id="ds-delete-dashboard-button"
                class="btn btn-danger"
                data-toggle="tooltip"
                title="Delete this dashboard">
          <i class="fa fa-trash-o"></i>
        </button>

        <!-- Source button -->
        <button type="button"
                id="ds-view-dashboard-source-button"
                class="btn btn-default"
                data-toggle="tooltip"
                title="View Source">
          <i class="fa fa-code"></i>

        <!-- New Section button -->
        <button type="button"
                id="ds-new-section-button"
                class="btn btn-default"
                data-toggle="tooltip"
                title="New Section">
          <i class="fa fa-plus"></i>
        </button>

        <!-- Save Dashboard button -->
        <button type="button"
                id="ds-save-dashboard-button"
                class="btn btn-default"
                data-toggle="tooltip"
                title="Save Dashboard">
          <i class="fa fa-save"></i> Save
        </button>


        </button>
      </div>


      <div class="btn-group">

        <!-- Edit button -->
        <button type="button" id="ds-edit-info-button" class="btn btn-default" data-toggle="tooltip" title="Edit" data-ds-hide="transform">
          <i class="fa fa-edit"></i>
        </button>

        <!-- Toggle interactive button -->
        <button data-ds-hide="edit transform" type="button" id="ds-toggle-interactive-button" class="btn btn-default {% if ctx.prefs.interactive %} {% else %} active {% endif %}" data-toggle="tooltip" title="Toggle Interactive Graphs">
          <i class="fa fa-lock"></i>
        </button>

        <button data-ds-show="transform" style="display:none;" class="btn btn-default" id="ds-remove-transform-button" data-toggle="tooltip" title="Back to full dashboard">
          <i class="fa fa-arrow-left"></i>
        </button>

        {% include "snippets/rejigger-button.html" %}

        {% include "snippets/refresh-button.html" %}

        <!-- Display mode button -->
        <button data-ds-hide="transform" type="button" id="ds-enter-fullscreen-button" class="btn btn-default" data-toggle="tooltip" title="Enter Display Mode">
          <i class="fa fa-expand"></i>
        </button>

      </div> <!-- btn-group -->

    </div> <!-- btn-toolbar -->
  </div>
</div> <!-- row -->

<script>

</script>
