<div class="btn-group ds-rejigger-button" data-ds-hide="transform">

  <button type="button" class="btn btn-default dropdown-toggle" data-toggle="dropdown" title="Auto Layout">
    <i class="fa fa-th"></i>
    <span class="caret"</span>
  </button>

  <ul class="dropdown-menu dropdown-menu-right ds-rejigger-menu" role="menu">
    <li role="presentation" class="dropdown-header"><i class="fa fa-th"></i> Fixed</li>
    <li class="divider"></li>
    <li data-ds-section-type="fixed" data-ds-cols="1"><a href="#">1 column</a></li>
    <li data-ds-section-type="fixed" data-ds-cols="2"><a href="#">2 columns</a></li>
    <li data-ds-section-type="fixed" data-ds-cols="3"><a href="#">3 columns</a></li>
    <li data-ds-section-type="fixed" data-ds-cols="4"><a href="#">4 columns</a></li>
    <br/>
    <li role="presentation" class="dropdown-header"><i class="fa fa-th"></i> Fluid</li>
    <li class="divider"></li>
    <li data-ds-section-type="fluid" data-ds-cols="1"><a href="#">1 column</a></li>
    <li data-ds-section-type="fluid" data-ds-cols="2"><a href="#">2 columns</a></li>
    <li data-ds-section-type="fluid" data-ds-cols="3"><a href="#">3 columns</a></li>
    <li data-ds-section-type="fluid" data-ds-cols="4"><a href="#">4 columns</a></li>
  </ul>

</div>
