
<title>{{config.get('DASHBOARD_APPNAME')}}: {{title}}</title>
<meta name="viewport" content="width=device-width, initial-scale=1.0"/>

<link  href="{{ url_for('static', filename='css/bundle.css') }}" rel="stylesheet"></link>
<link  href="{{ url_for('static', filename='themes/bootstrap-' + ctx.prefs.theme + '.css') }}" rel="stylesheet"></link>
<link  href="{{ url_for('static', filename='tessera-typography.css') }}" rel="stylesheet"></link>
<link  href="{{ url_for('static', filename='themes/tessera-' + ctx.prefs.theme + '.css') }}" rel="stylesheet"></link>
<link  href="{{ url_for('static', filename='tessera.css') }}" rel="stylesheet"></link>
<link  href="{{ url_for('static', filename='css/highlight-styles/github.css') }}" rel="stylesheet"></link>

<script src="{{ url_for('static', filename='bundle.js') }}"></script>
<script src="{{ url_for('static', filename='app.js') }}"></script>

<script>
  ds.config = ds.config || {}
  ds.config.GRAPHITE_URL = "{{ctx.get_str('graphite_url', config.get('GRAPHITE_URL'))}}"
  ds.config.DISPLAY_TIMEZONE = "{{ctx.get_str('timezone', config.get('DISPLAY_TIMEZONE','UTC'))}}"
  ds.config.DEFAULT_FROM_TIME = "{{config.get('DEFAULT_FROM_TIME')}}"
</script>
