/* =============================================================================
   Application Styles
   ============================================================================= */

.ds-grid h1,
.ds-grid h2 {
    color: #A95353;
}

.ds-grid h1 small,
.ds-grid h2 small {
    color: gray;
    font-family: "Helvetica Neue","Arial Narrow",Arial,sans-serif;
    font-weight: 100;
}

.ds-markdown h1,
.ds-markdown h2,
.ds-markdown h3,
.ds-markdown h4,
.ds-markdown h5,
.ds-markdown h6 {
    color: black;
}

.ds-singlestat h3 {
    color: #737380;
}

.well .ds-singlestat h3 {
    color: #A95353;
}

.ds-dashboard .well {
  background-color: rgba(0,0,0,0.07)
}

.ds-singlestat p {
    // color:white;
}

.ds-singlestat .unit,
.ds-jumbotron-singlestat .unit {
    color: gray;
}

.ds-jumbotron-singlestat .value {
    // color: white;
}

.ds-jumbotron-singlestat h3 {
    color: #a6a699;
}

h1 .ds-primary-title {
    color: gray;
}

h1 .ds-secondary-title {
    // color: white;
}

.ds-time-container h2 {
    // color: #ddd;
}

.ds-danger,
.ds-danger h3,
.ds-danger .value,
.ds-danger .unit {
    color: #d60000;
}

.ds-warning,
.ds-warning h3,
.ds-warning .value,
.ds-warning .unit {
    color: #d66a00;
}

#ds-tooltip {
    color: black;
    background-color: white;
    border: 1px solid #888;
}

.ds-singlegraph span.value {
    text-shadow: 1px 1px white;
}


/* =============================================================================
   3rd Party Tweaks
   ============================================================================= */

.nvd3 .nv-axis path {
    stroke: lightgray;
}

.bg-neutral {
    background-color: #f0f0f0;
}

.alert-neutral {
    background-color: #f0f0f0;
}

/* -----------------------------------------------------------------------------
   Edit mode headers
   ----------------------------------------------------------------------------- */

/*
 * Section
 */

.ds-badge-section {
    background-color: #387AA3;
}

.ds-edit-bar-section {
    background-color: #9DC2D3;
    border: 1px solid #387AA3;
}

/*
 * Row
 */

.ds-badge-row {
    background-color: #649EB9;
}

.ds-edit-bar-row {
    border: 1px solid #649EB9;
    background-color: #D9EDF7;
}

.ds-row.ds-edit {
    border: 1px solid #649EB9;
    border-radius: 4px;
}

/*
 * Cell
 */

.ds-badge-cell {
    background-color: #649EB9;
    border: 1px solid #9DC2D3;
}
.ds-edit-bar-cell {
    background-color: #E3F7FF;
    border: 1px solid #9DC2D3;
}

/*
 * Item
 */

.ds-badge-item {
    background-color: #D9EDF7;
    color: #387AA3;
    border: 1px solid #649EB9;
}

.ds-edit-bar-item {
    background-color: #FAFAFA;
    border: 1px solid #649EB9;
}
